@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps;
 use strict;
 use warnings;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Hash::Util 'lock_keys';
 use List::Util 'first';
@@ -269,6 +269,18 @@ sub _debug {
 sub _map_cpandist {
     my($self, $dist) = @_;
 
+    # compat for older CPAN.pm (1.76)
+    if (!$dist->can('base_id')) {
+	no warnings 'once';
+	*CPAN::Distribution::base_id = sub {
+	    my $self = shift;
+	    my $id = $self->id();
+	    my $base_id = File::Basename::basename($id);
+	    $base_id =~ s{\.(?:tar\.(bz2|gz|Z)|t(?:gz|bz)|zip)$}{}i;
+	    return $base_id;
+	};
+    }
+
     # smartmatch for regexp/string/array without ~~, 5.8.x compat!
     my $smartmatch = sub ($$) {
 	my($left, $right) = @_;
@@ -880,7 +892,7 @@ Slaven Rezic
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Slaven ReziE<x0107>
+Copyright (C) 2016,2017 by Slaven ReziE<x0107>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
