@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 # shortcuts
 #  os and distros
@@ -194,6 +194,13 @@ sub mapping {
       [like_debian,
        [package => 'libsamplerate0-dev']]],
 
+     [cpanmod => 'Audio::MPEG',
+      [os_freebsd,
+       [package => 'lame']], # restricted, no binary package available, must build from ports
+      [like_debian,
+       [package => 'libmp3lame-dev']], # but compilation fails
+     ],
+
      [cpanmod => 'Audio::Ofa',
       [os_freebsd,
        [package => 'libofa']],
@@ -240,9 +247,9 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => 'squeeze',
 	[package => 'libdb4.8-dev']],
-       [linuxdistrocodename => 'wheezy',
+       [linuxdistrocodename => ['wheezy', 'precise'],
 	[package => 'libdb5.1-dev']],
-       [package => 'libdb5.3-dev']],
+       [package => 'libdb5.3-dev']], # e.g. jessie, stretch, trusty, xenial, yakkety, zesty
       [os_darwin,
        # Make sure that a corresponding distroprefs file matches this library (see srezic-cpan-distroprefs).
        [package => 'berkeley-db']],
@@ -351,7 +358,7 @@ sub mapping {
       [like_debian,
        [package => 'libcrack2-dev']]],
 
-     [cpanmod => ['Crypt::DH::GMP', 'Math::GMPq', 'Math::GMPz'],
+     [cpanmod => ['Crypt::DH::GMP', 'Math::GMPq', 'Math::GMPz', 'Math::BigInt::GMP'],
       [os_freebsd,
        [package => 'gmp']],
       [like_debian,
@@ -407,7 +414,10 @@ sub mapping {
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => []], # not available before jessie
        ],
-       [package => 'libsodium-dev']]],
+       [package => 'libsodium-dev']],
+      [os_darwin,
+       [package => 'libsodium']],
+     ],
 
      [cpanmod => 'CSS::Croco',
       [os_freebsd,
@@ -463,10 +473,10 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => 'squeeze',
 	[package => 'libdb4.8-dev']],
-       [linuxdistrocodename => 'wheezy',
+       [linuxdistrocodename => ['wheezy', 'precise'],
 	[package => 'libdb5.1-dev']],
-       [package => 'libdb5.3-dev']],
-      # FreeBSD has libdb in the base system
+       [package => 'libdb5.3-dev']], # e.g. jessie, stretch, trusty, xenial, yakkety, zesty
+      # FreeBSD and MacOSX have libdb in the base system
      ],
 
      [cpanmod => 'DBD::Firebird',
@@ -507,11 +517,24 @@ sub mapping {
        [package => [qw(libzmq3-dev ipython ipython-notebook libmagic-dev)]], # as specified in https://metacpan.org/source/ZMUGHAL/Devel-IPerl-0.006/README.md
       ]],
 
+     [cpanmod => 'Devel::Valgrind::Client',
+      [os_freebsd,
+       [package => 'valgrind']], # untested
+      [like_debian,
+       [package => 'valgrind']], # but compilation errors
+     ],
+
      [cpanmod => 'Device::Cdio',
       [like_debian,
        # but still does not work
        [package => ['libcdio-dev', 'libiso9660-dev']]]],
 
+     [cpanmod => 'Device::Serdisp',
+      [os_freebsd,
+       [package => 'serdisplib']], # but segfault in tests
+      # no package for debian
+     ],
+
      [cpanmod => 'Device::Velleman::K8055::libk8055',
       [os_freebsd,
        [package => 'libk8055']],
@@ -527,7 +550,10 @@ sub mapping {
       [os_freebsd,
        [package => 'ldns']],
       [like_debian,
-       [package => 'libldns-dev']]],
+       [package => 'libldns-dev']],
+      # additionally needs to be patched, see https://github.com/eserte/srezic-cpan-distroprefs/blob/master/DNS-LDNS.yml
+      [os_darwin,
+       [package => 'ldns']]],
 
      [cpanmod => 'DVD::Read',
       [os_freebsd,
@@ -601,6 +627,14 @@ sub mapping {
       [like_debian,
        [package => 'librsync-dev']]],
 
+     [cpanmod => 'Filesys::SmbClient',
+      ## XXX unclear which package is the correct one
+      #[os_freebsd,
+      # [package => 'samba-libsmbclient | samba41 | samba4']],
+      [like_debian,
+       [package => 'libsmbclient-dev']],
+     ],
+
      [cpanmod => 'Finance::MICR::GOCR::Check',
       [package => 'gocr']],
 
@@ -618,6 +652,27 @@ sub mapping {
       [like_debian,
        [package => 'libfuse-dev']]],
 
+     [cpanmod => 'Games::Chipmunk',
+      [os_freebsd,
+       [package => 'ChipmunkPhysics']],
+      [like_debian,
+       [package => 'chipmunk-dev']],
+     ],
+
+     [cpanmod => 'Games::Irrlicht',
+      [os_freebsd,
+       [package => 'irrlicht']], # but does not build
+      [like_debian,
+       [package => 'libirrlicht-dev']], # but does not build
+     ],
+
+     [cpanmod => 'Games::Poker::HandEvaluator',
+      [os_freebsd,
+       [package => 'poker-eval']], # but does not build out of the box
+      [like_debian,
+       [package => 'libpoker-eval-dev']], # but does not build out of the box
+     ],
+
      [cpanmod => 'GD',
       [os_freebsd,
        [package => 'libgd']],
@@ -837,6 +892,18 @@ sub mapping {
       [like_debian,
        [package => 'libsoup-gnome2.4-dev']]],
 
+     [cpanmod => 'Image::DecodeQR',
+      #[os_freebsd,
+      # [package => 'opencv']], # package for decodeqr missing
+      [like_debian,
+       [package => ['libopencv-dev', 'libdecodeqr-dev']]]],
+
+     [cpanmod => ['Image::ObjectDetect', 'Image::Resize::OpenCV'],
+      [os_freebsd,
+       [package => 'opencv']],
+      [like_debian,
+       [package => 'libopencv-dev']]],
+
      [cpanmod => 'Image::GeoTIFF::Tiled',
       [os_freebsd,
        [package => ['libgeotiff', 'tiff']]],
@@ -907,7 +974,7 @@ sub mapping {
       [os_freebsd,
        [package => [qw(freetype2 giflib png tiff), freebsd_jpeg]]], # in former days giflib-nox11 had to be specified
       [like_debian,
-       [linuxdistrocodename => 'wheezy',
+       [linuxdistrocodename => ['wheezy', 'precise'],
 	[package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev), 'libtiff5-dev | libtiff4-dev']]],
        [package => [qw(libfreetype6-dev libgif-dev libpng12-dev libjpeg-dev libtiff5-dev)]]],
       [os_darwin,
@@ -970,9 +1037,28 @@ sub mapping {
        [package => 'v8']], # but compilation errors (v8-5.0.71.33 <-> JavaScript-V8-0.07)
      ],
 
+     [cpanmod => 'Jq',
+      [os_freebsd,
+       [package => 'jq']],
+      [like_debian,
+       [package => 'jq']],
+      [os_darwin,
+       [package => 'jq']],
+     ],
+
 #	# for some Judy-using modules (XXX which one?)
 #	package { "Judy": ensure => installed } # XXX this is freebsd; what about debian?
 
+     [cpanmod => 'Kafka::Librd',
+      # no package for freebsd
+      [like_debian,
+       [package => 'librdkafka-dev']]],
+
+     [cpanmod => 'Kernel::Keyring',
+      # linux-only
+      [like_debian,
+       [package => 'libkeyutils-dev']]],
+
      # XXX needs verification; maybe more latex-related modules should be listed here?
      [cpanmod => ['LaTeX::Driver', 'Template::Plugin::Latex'],
       [os_freebsd,
@@ -1042,7 +1128,11 @@ sub mapping {
        [linuxdistrocodename => ['squeeze', 'wheezy'],
 	[package => []], # not available before jessie
        ],
-       [package => 'liblmdb-dev']]],
+       [package => 'liblmdb-dev']],
+      ## does not work, maybe Makefile.PL needs better detection?
+      #[os_darwin,
+      # [package => 'lmdb']],
+     ],
 
      [cpanmod => 'Locale::gettext', # gettext distribution
       [os_freebsd,
@@ -1088,11 +1178,14 @@ sub mapping {
       [package => 'gap'], # needs 1-1.2GB of disk space
      ],
 
-     [cpanmod => 'Math::GSL',
+     [cpanmod => ['Math::GSL', 'PerlGSL::DiffEq'],
       [os_freebsd,
        [package => 'gsl']],
       [like_debian,
-       [package => 'libgsl0-dev']]],
+       [package => 'libgsl0-dev']],
+      [os_darwin,
+       [package => 'gsl']],
+     ],
 
      [cpanmod => 'Math::MPC',
       [os_freebsd,
@@ -1118,6 +1211,13 @@ sub mapping {
       # XXX what about debian?
      ],
 
+     [cpanmod => 'Mhash',
+      [os_freebsd,
+       [package => 'mhash']],
+      [like_debian,
+       [package => 'libmhash-dev']],
+     ],
+
      [cpanmod => 'MIDI::ALSA',
       [os_freebsd,
        [package => ['alsa-lib', 'alsa-utils']]],
@@ -1272,7 +1372,10 @@ sub mapping {
       [like_debian,
        [linuxdistrocodename => 'squeeze',
 	[package => []]], # not available
-       [package => ['libzookeeper-mt-dev', 'zookeeperd']]]],
+       [package => ['libzookeeper-mt-dev', 'zookeeperd']]],
+      [os_darwin,
+       [package => 'zookeeper']],
+     ],
 
      [cpanmod => 'NewRelic::Agent',
       # freebsd does not work, bundled .so files are linux-only
@@ -1430,7 +1533,8 @@ sub mapping {
      [cpanmod => 'Speech::Recognizer::SPX',
       [os_freebsd,
        [package => 'pocketsphinx']],
-      # XXX what about debian?
+      [like_debian,
+       [package => ['libpocketsphinx-dev', 'libsphinxbase-dev']]],
      ],
 
      [cpanmod => 'Spread',
@@ -1596,7 +1700,7 @@ sub mapping {
       [os_freebsd,
        [package => 'tiff']],
       [like_debian,
-       [linuxdistrocodename => ['squeeze', 'wheezy'],
+       [linuxdistrocodename => ['squeeze', 'wheezy', 'precise'],
 	[package => 'libtiff4-dev']],
        [package => 'libtiff5-dev']]],
 
